@@ -1,15 +1,15 @@
 #include "krulertest.h"
 
-#include <kruler.h>
+#include <KRuler>
 
 #include <QApplication>
-#include <QLayout>
-#include <QLabel>
-#include <QKeyEvent>
-#include <QGroupBox>
 #include <QButtonGroup>
-#include <QSpinBox>
 #include <QDoubleSpinBox>
+#include <QGroupBox>
+#include <QKeyEvent>
+#include <QLabel>
+#include <QLayout>
+#include <QSpinBox>
 
 /*
 void
@@ -25,22 +25,19 @@ MouseWidget::MouseWidget(QWidget *parent)
 {
 }
 
-void
-MouseWidget::mousePressEvent(QMouseEvent *e)
+void MouseWidget::mousePressEvent(QMouseEvent *e)
 {
     mouseButtonDown = true;
     Q_EMIT newXPos(e->x());
     Q_EMIT newYPos(e->y());
 }
 
-void
-MouseWidget::mouseReleaseEvent(QMouseEvent *)
+void MouseWidget::mouseReleaseEvent(QMouseEvent *)
 {
     mouseButtonDown = false;
 }
 
-void
-MouseWidget::mouseMoveEvent(QMouseEvent *e)
+void MouseWidget::mouseMoveEvent(QMouseEvent *e)
 {
     if (mouseButtonDown) {
         Q_EMIT newXPos(e->x());
@@ -48,8 +45,7 @@ MouseWidget::mouseMoveEvent(QMouseEvent *e)
     }
 }
 
-void
-MouseWidget::resizeEvent(QResizeEvent *r)
+void MouseWidget::resizeEvent(QResizeEvent *r)
 {
     Q_EMIT newWidth(r->size().width());
     Q_EMIT newHeight(r->size().height());
@@ -82,14 +78,10 @@ KRulerTest::KRulerTest()
     vruler->setOffset(0);
     vruler->setRange(0, 1000);
 
-    connect(bigwidget, SIGNAL(newXPos(int)),
-            hruler, SLOT(slotNewValue(int)));
-    connect(bigwidget, SIGNAL(newYPos(int)),
-            vruler, SLOT(slotNewValue(int)));
-    connect(bigwidget, SIGNAL(newWidth(int)),
-            SLOT(slotNewWidth(int)));
-    connect(bigwidget, SIGNAL(newHeight(int)),
-            SLOT(slotNewHeight(int)));
+    connect(bigwidget, &MouseWidget::newXPos, hruler, &KRuler::slotNewValue);
+    connect(bigwidget, &MouseWidget::newYPos, vruler, &KRuler::slotNewValue);
+    connect(bigwidget, &MouseWidget::newWidth, this, &KRulerTest::slotNewWidth);
+    connect(bigwidget, &MouseWidget::newHeight, this, &KRulerTest::slotNewHeight);
 
     layout->addWidget(miniwidget, 0, 0);
     layout->addWidget(hruler, 0, 1);
@@ -107,38 +99,38 @@ KRulerTest::KRulerTest()
     showTM->adjustSize();
     showTM->move(5, 15);
     showTM->setChecked(true);
-    connect(showTM, SIGNAL(toggled(bool)), SLOT(slotSetTinyMarks(bool)));
+    connect(showTM, &QCheckBox::toggled, this, &KRulerTest::slotSetTinyMarks);
     showLM = new QCheckBox(QStringLiteral("show little marks"), showMarks);
     showLM->adjustSize();
     showLM->move(5, 35);
     showLM->setChecked(true);
-    connect(showLM, SIGNAL(toggled(bool)), SLOT(slotSetLittleMarks(bool)));
+    connect(showLM, &QCheckBox::toggled, this, &KRulerTest::slotSetLittleMarks);
     showMM = new QCheckBox(QStringLiteral("show medium marks"), showMarks);
     showMM->adjustSize();
     showMM->move(5, 55);
     showMM->setChecked(true);
-    connect(showMM, SIGNAL(toggled(bool)), SLOT(slotSetMediumMarks(bool)));
+    connect(showMM, &QCheckBox::toggled, this, &KRulerTest::slotSetMediumMarks);
     showBM = new QCheckBox(QStringLiteral("show big marks"), showMarks);
     showBM->adjustSize();
     showBM->move(5, 75);
     showBM->setChecked(true);
-    connect(showBM, SIGNAL(toggled(bool)), SLOT(slotSetBigMarks(bool)));
+    connect(showBM, &QCheckBox::toggled, this, &KRulerTest::slotSetBigMarks);
     showEM = new QCheckBox(QStringLiteral("show end marks"), showMarks);
     showEM->adjustSize();
     showEM->move(5, 95);
     showEM->setChecked(true);
-    connect(showEM, SIGNAL(toggled(bool)), SLOT(slotSetEndMarks(bool)));
+    connect(showEM, &QCheckBox::toggled, this, &KRulerTest::slotSetEndMarks);
     showPT = new QCheckBox(QStringLiteral("show ruler pointer"), showMarks);
     showPT->adjustSize();
     showPT->move(5, 115);
     showPT->setChecked(true);
-    connect(showPT, SIGNAL(toggled(bool)), SLOT(slotSetRulerPointer(bool)));
+    connect(showPT, &QCheckBox::toggled, this, &KRulerTest::slotSetRulerPointer);
     fixLen = new QCheckBox(QStringLiteral("fix ruler length"), showMarks);
     fixLen->adjustSize();
     fixLen->move(5, 135);
     fixLen->setChecked(true);
-    connect(fixLen, SIGNAL(toggled(bool)), SLOT(slotFixRulerLength(bool)));
-    connect(fixLen, SIGNAL(toggled(bool)), SLOT(slotCheckLength(bool)));
+    connect(fixLen, &QCheckBox::toggled, this, &KRulerTest::slotFixRulerLength);
+    connect(fixLen, &QCheckBox::toggled, this, &KRulerTest::slotCheckLength);
 
     lineEdit = new QGroupBox(QStringLiteral("Value of begin/end"), bigwidget);
     lineEdit->setFixedSize(140, 80);
@@ -148,28 +140,22 @@ KRulerTest::KRulerTest()
     beginMark->setRange(-1000, 1000);
     beginMark->move(5, 15);
     beginMark->setFixedSize(beginMark->sizeHint());
-    connect(beginMark, SIGNAL(valueChanged(int)),
-            hruler, SLOT(slotNewOffset(int)));
-    connect(beginMark, SIGNAL(valueChanged(int)),
-            vruler, SLOT(slotNewOffset(int)));
+    connect(beginMark, qOverload<int>(&QSpinBox::valueChanged), hruler, &KRuler::slotNewOffset);
+    connect(beginMark, qOverload<int>(&QSpinBox::valueChanged), vruler, &KRuler::slotNewOffset);
     endMark = new QSpinBox(lineEdit);
     endMark->setValue(0);
     endMark->setRange(-1000, 1000);
     endMark->move(5, 35);
     endMark->setFixedSize(endMark->sizeHint());
-    connect(endMark, SIGNAL(valueChanged(int)),
-            hruler, SLOT(slotEndOffset(int)));
-    connect(endMark, SIGNAL(valueChanged(int)),
-            vruler, SLOT(slotEndOffset(int)));
+    connect(endMark, qOverload<int>(&QSpinBox::valueChanged), hruler, &KRuler::slotEndOffset);
+    connect(endMark, qOverload<int>(&QSpinBox::valueChanged), vruler, &KRuler::slotEndOffset);
     lengthInput = new QSpinBox(lineEdit);
     lengthInput->setValue(0);
     lengthInput->setRange(-1000, 1000);
     lengthInput->move(5, 55);
     lengthInput->setFixedSize(lengthInput->sizeHint());
-    connect(lengthInput, SIGNAL(valueChanged(int)),
-            hruler, SLOT(slotEndOffset(int)));
-    connect(lengthInput, SIGNAL(valueChanged(int)),
-            vruler, SLOT(slotEndOffset(int)));
+    connect(lengthInput, qOverload<int>(&QSpinBox::valueChanged), hruler, &KRuler::slotEndOffset);
+    connect(lengthInput, qOverload<int>(&QSpinBox::valueChanged), vruler, &KRuler::slotEndOffset);
 
     vertrot = new QGroupBox(QStringLiteral("Value of rotate translate for Vert."), bigwidget);
     vertrot->setFixedSize(140, 80);
@@ -180,27 +166,24 @@ KRulerTest::KRulerTest()
     transX->setSingleStep(1);
     transX->move(5, 15);
     transX->setFixedSize(transX->sizeHint());
-    //transX->setLabel("transx", AlignLeft);
-    connect(transX, SIGNAL(valueChanged(double)),
-            SLOT(slotSetXTrans(double)));
+    // transX->setLabel("transx", AlignLeft);
+    connect(transX, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &KRulerTest::slotSetXTrans);
     transY = new QDoubleSpinBox(vertrot);
     transY->setValue(-12.0);
     transY->setRange(-1000, 1000);
     transY->setSingleStep(1);
     transY->move(5, 35);
     transY->setFixedSize(transY->sizeHint());
-    //transY->setLabel("transy", AlignLeft);
-    connect(transY, SIGNAL(valueChanged(double)),
-            SLOT(slotSetYTrans(double)));
+    // transY->setLabel("transy", AlignLeft);
+    connect(transY, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &KRulerTest::slotSetYTrans);
     rotV = new QDoubleSpinBox(vertrot);
     rotV->setValue(90.0);
     rotV->setRange(-1000, 1000);
     rotV->setSingleStep(1);
     rotV->move(5, 55);
     rotV->setFixedSize(rotV->sizeHint());
-    //rotV->setLabel("rot", AlignLeft);
-    connect(rotV, SIGNAL(valueChanged(double)),
-            SLOT(slotSetRotate(double)));
+    // rotV->setLabel("rot", AlignLeft);
+    connect(rotV, qOverload<double>(&QDoubleSpinBox::valueChanged), this, &KRulerTest::slotSetRotate);
 
     metricstyle = new QGroupBox(QStringLiteral("metric styles"), bigwidget);
 
@@ -228,7 +211,9 @@ KRulerTest::KRulerTest()
     mmetric->adjustSize();
     mmetric->move(5, 95);
     metricstyleButtons->addButton(mmetric, (int)KRuler::Metres);
-    connect(metricstyleButtons, SIGNAL(buttonClicked(int)), SLOT(slotSetMStyle(int)));
+    connect(metricstyleButtons, &QButtonGroup::buttonClicked, this, [this, metricstyleButtons](QAbstractButton *button) {
+        slotSetMStyle(metricstyleButtons->id(button));
+    });
 
     slotUpdateShowMarks();
 }
@@ -243,84 +228,72 @@ KRulerTest::~KRulerTest()
     delete mainframe;
 }
 
-void
-KRulerTest::slotNewWidth(int width)
+void KRulerTest::slotNewWidth(int width)
 {
     hruler->setMaximum(width);
 }
 
-void
-KRulerTest::slotNewHeight(int height)
+void KRulerTest::slotNewHeight(int height)
 {
     vruler->setMaximum(height);
 }
 
-void
-KRulerTest::slotSetTinyMarks(bool set)
+void KRulerTest::slotSetTinyMarks(bool set)
 {
     hruler->setShowTinyMarks(set);
     vruler->setShowTinyMarks(set);
 }
 
-void
-KRulerTest::slotSetLittleMarks(bool set)
+void KRulerTest::slotSetLittleMarks(bool set)
 {
     hruler->setShowLittleMarks(set);
     vruler->setShowLittleMarks(set);
 }
 
-void
-KRulerTest::slotSetMediumMarks(bool set)
+void KRulerTest::slotSetMediumMarks(bool set)
 {
     hruler->setShowMediumMarks(set);
     vruler->setShowMediumMarks(set);
 }
 
-void
-KRulerTest::slotSetBigMarks(bool set)
+void KRulerTest::slotSetBigMarks(bool set)
 {
     hruler->setShowBigMarks(set);
     vruler->setShowBigMarks(set);
 }
 
-void
-KRulerTest::slotSetEndMarks(bool set)
+void KRulerTest::slotSetEndMarks(bool set)
 {
     hruler->setShowEndMarks(set);
     vruler->setShowEndMarks(set);
 }
 
-void
-KRulerTest::slotSetRulerPointer(bool set)
+void KRulerTest::slotSetRulerPointer(bool set)
 {
     hruler->setShowPointer(set);
     vruler->setShowPointer(set);
 }
 
-void
-KRulerTest::slotSetRulerLength(int len)
+void KRulerTest::slotSetRulerLength(int len)
 {
     hruler->setLength(len);
     vruler->setLength(len);
 }
 
-void
-KRulerTest::slotFixRulerLength(bool fix)
+void KRulerTest::slotFixRulerLength(bool fix)
 {
     hruler->setLengthFixed(fix);
     vruler->setLengthFixed(fix);
 }
 
-void
-KRulerTest::slotSetMStyle(int style)
+void KRulerTest::slotSetMStyle(int style)
 {
     hruler->setRulerMetricStyle((KRuler::MetricStyle)style);
     vruler->setRulerMetricStyle((KRuler::MetricStyle)style);
     slotUpdateShowMarks();
 }
 
-void
-KRulerTest::slotUpdateShowMarks()
+void KRulerTest::slotUpdateShowMarks()
 {
     showTM->setChecked(hruler->showTinyMarks());
     showLM->setChecked(hruler->showLittleMarks());
@@ -329,8 +302,7 @@ KRulerTest::slotUpdateShowMarks()
     showEM->setChecked(hruler->showEndMarks());
 }
 
-void
-KRulerTest::slotCheckLength(bool fixlen)
+void KRulerTest::slotCheckLength(bool fixlen)
 {
     Q_UNUSED(fixlen);
     beginMark->setValue(hruler->offset());
@@ -338,45 +310,43 @@ KRulerTest::slotCheckLength(bool fixlen)
     lengthInput->setValue(hruler->length());
 }
 
-void
-KRulerTest::slotSetRotate(double d)
+void KRulerTest::slotSetRotate(double d)
 {
     Q_UNUSED(d);
 #ifdef KRULER_ROTATE_TEST
     vruler->rotate = d;
     vruler->update();
-    //debug("rotate %.1f", d);
+    // debug("rotate %.1f", d);
 #endif
 }
 
-void
-KRulerTest::slotSetXTrans(double d)
+void KRulerTest::slotSetXTrans(double d)
 {
     Q_UNUSED(d);
 #ifdef KRULER_ROTATE_TEST
     vruler->xtrans = d;
     vruler->update();
-    //debug("trans x %.1f", d);
+    // debug("trans x %.1f", d);
 #endif
 }
 
-void
-KRulerTest::slotSetYTrans(double d)
+void KRulerTest::slotSetYTrans(double d)
 {
     Q_UNUSED(d);
 #ifdef KRULER_ROTATE_TEST
     vruler->ytrans = d;
     vruler->update();
-    //debug("trans y %.1f", d);
+    // debug("trans y %.1f", d);
 #endif
 }
 
 /* --- MAIN -----------------------*/
 int main(int argc, char **argv)
 {
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication::setApplicationName(QStringLiteral("test"));
     QApplication *testapp;
-    KRulerTest   *window;
+    KRulerTest *window;
 
     testapp = new QApplication(argc, argv);
     testapp->setFont(QFont(QStringLiteral("Helvetica"), 12));
@@ -387,4 +357,3 @@ int main(int argc, char **argv)
     window->show();
     return testapp->exec();
 }
-
